# flake8: noqa

# import apis into api package
from OSCR_django_client.api.combatlog_api import CombatlogApi
from OSCR_django_client.api.ladder_api import LadderApi
from OSCR_django_client.api.ladder_entries_api import LadderEntriesApi
from OSCR_django_client.api.variant_api import VariantApi




# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.variant_list200_response import VariantList200Response

class TestVariantList200Response(unittest.TestCase):
    """VariantList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> VariantList200Response:
        """Test VariantList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `VariantList200Response`
        """
        model = VariantList200Response()
        if include_optional:
            return VariantList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.variant.Variant(
                        name = '0', 
                        start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_ground_variant = True, 
                        is_space_variant = True, 
                        exclude_space = [
                            ''
                            ], 
                        exclude_ground = [
                            ''
                            ], )
                    ]
            )
        else:
            return VariantList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.variant.Variant(
                        name = '0', 
                        start_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        end_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        is_ground_variant = True, 
                        is_space_variant = True, 
                        exclude_space = [
                            ''
                            ], 
                        exclude_ground = [
                            ''
                            ], )
                    ],
        )
        """

    def testVariantList200Response(self):
        """Test VariantList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.combatlog_list200_response import CombatlogList200Response

class TestCombatlogList200Response(unittest.TestCase):
    """CombatlogList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CombatlogList200Response:
        """Test CombatlogList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CombatlogList200Response`
        """
        model = CombatlogList200Response()
        if include_optional:
            return CombatlogList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.combat_log.CombatLog(
                        id = 56, 
                        metadata = OSCR_django_client.models.metadata.Metadata(
                            id = 56, 
                            map = '0', 
                            difficulty = '0', 
                            summary = OSCR_django_client.models.summary.Summary(), 
                            date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        youtube = '0', )
                    ]
            )
        else:
            return CombatlogList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.combat_log.CombatLog(
                        id = 56, 
                        metadata = OSCR_django_client.models.metadata.Metadata(
                            id = 56, 
                            map = '0', 
                            difficulty = '0', 
                            summary = OSCR_django_client.models.summary.Summary(), 
                            date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        youtube = '0', )
                    ],
        )
        """

    def testCombatlogList200Response(self):
        """Test CombatlogList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder_entry import LadderEntry

class TestLadderEntry(unittest.TestCase):
    """LadderEntry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LadderEntry:
        """Test LadderEntry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LadderEntry`
        """
        model = LadderEntry()
        if include_optional:
            return LadderEntry(
                id = 56,
                var_date = '',
                rank = 56,
                player = '0',
                data = OSCR_django_client.models.data.Data(),
                combatlog = 56,
                ladder = 56
            )
        else:
            return LadderEntry(
                player = '0',
                data = OSCR_django_client.models.data.Data(),
                combatlog = 56,
                ladder = 56,
        )
        """

    def testLadderEntry(self):
        """Test LadderEntry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.ladder_list200_response import LadderList200Response

class TestLadderList200Response(unittest.TestCase):
    """LadderList200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LadderList200Response:
        """Test LadderList200Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LadderList200Response`
        """
        model = LadderList200Response()
        if include_optional:
            return LadderList200Response(
                count = 56,
                next = '',
                previous = '',
                results = [
                    OSCR_django_client.models.ladder.Ladder(
                        id = 56, 
                        variant_name = '', 
                        name = '0', 
                        difficulty = '0', 
                        is_solo = True, 
                        is_space = True, 
                        metric = '0', 
                        variant = '', )
                    ]
            )
        else:
            return LadderList200Response(
                count = 56,
                results = [
                    OSCR_django_client.models.ladder.Ladder(
                        id = 56, 
                        variant_name = '', 
                        name = '0', 
                        difficulty = '0', 
                        is_solo = True, 
                        is_space = True, 
                        metric = '0', 
                        variant = '', )
                    ],
        )
        """

    def testLadderList200Response(self):
        """Test LadderList200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OSCR API

    OSCR API

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from OSCR_django_client.models.metadata import Metadata

class TestMetadata(unittest.TestCase):
    """Metadata unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Metadata:
        """Test Metadata
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Metadata`
        """
        model = Metadata()
        if include_optional:
            return Metadata(
                id = 56,
                map = '0',
                difficulty = '0',
                summary = OSCR_django_client.models.summary.Summary(),
                date_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return Metadata(
                map = '0',
                summary = OSCR_django_client.models.summary.Summary(),
        )
        """

    def testMetadata(self):
        """Test Metadata"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
